@@ -91,10 +91,10 @@ typedef void (* authentication_cb_t) (struct connman_service *service,
 				const char *name, int name_len,
 				const char *identifier, const char *secret,
 				gboolean wps, const char *wpspin,
-				void *user_data);
+				const char *error, void *user_data);
 typedef void (* browser_authentication_cb_t) (struct connman_service *service,
 				connman_bool_t authentication_done,
-				void *user_data);
+				const char *error, void *user_data);
 typedef void (* report_error_cb_t) (struct connman_service *service,
 				gboolean retry, void *user_data);
 int __connman_agent_request_passphrase_input(struct connman_service *service,
@@ -369,6 +369,8 @@ void __connman_timeserver_cleanup(void);
 
 char **__connman_timeserver_system_get();
 
+GSList *__connman_timeserver_add_list(GSList *server_list,
+		const char *timeserver);
 GSList *__connman_timeserver_get_all(struct connman_service *service);
 int __connman_timeserver_sync(struct connman_service *service);
 void __connman_timeserver_sync_next();
@@ -594,6 +596,8 @@ int __connman_service_set_favorite(struct connman_service *service,
 						connman_bool_t favorite);
 int __connman_service_set_immutable(struct connman_service *service,
 						connman_bool_t immutable);
+void __connman_service_set_userconnect(struct connman_service *service,
+						connman_bool_t userconnect);
 
 void __connman_service_set_string(struct connman_service *service,
 					const char *key, const char *value);
@@ -641,6 +645,7 @@ void __connman_service_set_pac(struct connman_service *service,
 connman_bool_t __connman_service_is_hidden(struct connman_service *service);
 connman_bool_t __connman_service_is_split_routing(struct connman_service *service);
 int __connman_service_get_index(struct connman_service *service);
+void __connman_service_set_hidden(struct connman_service *service);
 void __connman_service_set_domainname(struct connman_service *service,
 						const char *domainname);
 const char *__connman_service_get_domainname(struct connman_service *service);
